autowisp.database.data_model package — AutoWISP documentation

# autowisp.database.data_model package

## Class Inheritance Diagram

Add all tables to __all__.

class autowisp.database.data_model.Condition(**kwargs)

  Bases: `DataModelBase`

  The table describing the Conditions for given configuration to apply.

  Each condition is a combination of condition expressions that must all be satisfied simultaneously for the condition to be considered satisfied.

  expression
  expression_id

    The id of the condition expression that is part of this condition.

  id

    A unique identifier for each row.

  notes

    Any user supplied notes describing the condition.

  timestamp

    When record was last changed

class autowisp.database.data_model.ConditionExpression(**kwargs)

  Bases: `DataModelBase`

  The table describing the Condition Expressions

  expression

    The expression to evaluate to determine if an image meets the condition.

  id

    A unique identifier for each row.

  notes

    Any user supplied notes describing the condition expression.

  timestamp

    When record was last changed

class autowisp.database.data_model.Configuration(**kwargs)

  Bases: `DataModelBase`

  Table recording the values of the pipeline configuration parameters.

  condition_expressions
  condition_id

    The id of the condition that must be met for this configuration to apply

  conditions: Mapped[List[Condition]]
  id

    A unique identifier for each row.

  notes

    Any user supplied notes describing the configuration.

  parameter
  parameter_id

    The name of the configuration parameter.

  timestamp

    When record was last changed

  value

    The value of the configuration parameter for the given version for images satisfying the given conditions.

  version

    The version of the configuration parameter. Later versions fall back on earlier versions if an entry for the parameter is not found.

class autowisp.database.data_model.HDF5Attribute(**kwargs)

  Bases: `DataModelBase`

  The table describing how to add attributes in HDF5 files.

  __str__()

    Print the contents of the given attribute.

  description

    A brief description of what this attribute tracks.

  dtype

    The data type to use for this dataset. See h5py for possible values and their meanings.

  hdf5_structure_version_id

    Which structure version of which pipeline product is this element configuration for.

  id

    A unique identifier for each row.

  name

    The name to give to use for this attribute within the HDF5 file.

  parent

    The full absolute path to the group or dataset to add this attribute to.

  pipeline_key

    How is this attribute referred to by the pipeline.

  structure_version
  timestamp

    When record was last changed

class autowisp.database.data_model.HDF5DataSet(**kwargs)

  Bases: `DataModelBase`

  The table describing how to include datasets in HDF5 files.

  __str__()

    Human readable description.

  abspath

    The full absolute path to the dataset within the HDF5 file.

  compression

    If not NULL, which compression filter to use when creating the dataset.

  compression_options

    Any options to pass to the compression filter. For gzip, this is passed as int(compression_options).

  description

    A brief description of what this attribute tracks.

  dtype

    The data type to use for this dataset. See h5py for possible values and their meanings.

  hdf5_structure_version_id

    Which structure version of which pipeline product is this element configuration for.

  id

    A unique identifier for each row.

  pipeline_key

    How is this dataset referred to by the pipeline.

  replace_nonfinite

    For numeric datasets, if this is not NULL, any non-finite values are replaced by this value.

  scaleoffset

    If not null, enable the scale/offset filter for this dataset with the specified precision.

  shuffle

    Should the shuffle filter be enabled?

  structure_version
  timestamp

    When record was last changed

class autowisp.database.data_model.HDF5Link(**kwargs)

  Bases: `DataModelBase`

  Table describing links of chosen versions of products in HDF5 files.

  abspath

    The full absolute path to the link in the HDF5 file.

  description

    A brief description of what this attribute tracks.

  hdf5_structure_version_id

    Which structure version of which pipeline product is this element configuration for.

  id

    A unique identifier for each row.

  pipeline_key

    How is this link referred to by the pipeline.

  structure_version
  target

    The full absolute path the link should point to.

  timestamp

    When record was last changed

class autowisp.database.data_model.HDF5Product(**kwargs)

  Bases: `DataModelBase`

  The types of pipeline products stored as HDF5 files.

  description

    A description of the product type.

  id

    A unique identifier for each row.

  pipeline_key

    How is this product referred to in the pipeline (e.g. “datareduction” or “lightcurve”

  structure_versions
  timestamp

    When record was last changed

class autowisp.database.data_model.HDF5StructureVersion(**kwargs)

  Bases: `DataModelBase`

  The versions of structures for the HDF5 pipeline products.

  attributes
  datasets
  hdf5_product_id

    The type of pipeline product this structure configuration version is for.

  id

    A unique identifier for each row.

  links
  product
  timestamp

    When record was last changed

  version

    An identifier for distinguishing the separate configuration versions of a single pipeline product type.

class autowisp.database.data_model.Image(**kwargs)

  Bases: `DataModelBase`

  The table describing the image specified

  id

    A unique identifier for each row.

  image_type
  image_type_id

    The id of the image type

  notes

    The notes provided for the image

  observing_session
  observing_session_id

    The id of the observing session

  processing: Mapped[List[ProcessedImages]]
  raw_fname

    The full path of the raw image

  timestamp

    When record was last changed

class autowisp.database.data_model.ImageProcessingProgress(**kwargs)

  Bases: `DataModelBase`

  The table describing the Image Processing Progress

  applied_to: Mapped[List[ProcessedImages]]
  configuration_version

    config version of image

  finished

    The time processing is known to have ended (NULL if possibly still on-going)

  host

    Hostname or other identifier of the computer where processing is/was done

  id

    A unique identifier for each row.

  image_type
  image_type_id

    The id of the image type being processed

  notes

    Any user supplied notes about the processing.

  process_id

    Identifier of the process performing this calibration step

  started

    The time processing started

  step
  step_id

    Id of the step that was applied

  timestamp

    When record was last changed

class autowisp.database.data_model.ImageType(**kwargs)

  Bases: `DataModelBase`

  The table describing the different image types.

  description

    The description of the image type

  id

    A unique identifier for each row.

  image
  name

    The image type name

  timestamp

    When record was last changed

class autowisp.database.data_model.InputMasterTypes(**kwargs)

  Bases: `DataModelBase`

  The table describing the prerequisites for a step to run

  config_name

    The name of the configuration parameter that specifies the master when running the specified step.

  id

    A unique identifier for each row.

  image_type
  image_type_id

    The image type for which this prerequisite applies.

  master_type
  master_type_id

    The master type required for the step to run.

  optional

    Can processing by the given step of the given types of images can proceed if the given type of master is not found?

  step
  step_id

    The step for which this prerequisite applies.

  timestamp

    When record was last changed

class autowisp.database.data_model.LightCurveProcessingProgress(**kwargs)

  Bases: `DataModelBase`

  The table describing the light curve processing progress

  configuration_version

    config version of image

  final

    Is this the final processing status? The only case where `status=1` is not final is for magnitude fitting, where there may be additional iterations needed.

  finished

    The time processing is known to have ended (NULL if possibly still on-going)

  host

    Hostname or other identifier of the computer where processing is/was done

  id

    A unique identifier for each row.

  notes

    Any user supplied notes about the processing.

  process_id

    Identifier of the process performing this calibration step

  single_photref_id

    The ID of the single photometric reference for which LC points were processed.

  sphotref
  started

    The time processing started

  step
  step_id

    Id of the step that was applied

  timestamp

    When record was last changed

class autowisp.database.data_model.LightCurveStatus(**kwargs)

  Bases: `DataModelBase`

  Table tracking the status of lightcurves for interrupted steps.

  id

    A unique identifier for each row.

  processing
  progress_id

    The ID of the LC processing progress which was interrupted

  status

    The status of the processing (0 = started, >0 = successfully saved progress, negative values indicate various reasons for failure).

  timestamp

    When record was last changed

class autowisp.database.data_model.MasterFile(**kwargs)

  Bases: `DataModelBase`

  The table tracking master files generated and used by the pipeline.

  enabled

    Can this master be used for calibrations?

  filename

    The full path of the master file.

  id

    A unique identifier for each row.

  master_type
  progress_id

    The ImageProcessingProgress or LightCurveProcessingProgress that generated this master, if any.

  timestamp

    When record was last changed

  type_id

    The type of master file.

  use_smallest

    Use the master of this type for which this expression evaluated against image header gives the smallest value

class autowisp.database.data_model.MasterType(**kwargs)

  Bases: `DataModelBase`

  The table tracking the types of master files used by the pipeline.

  condition_id

    The collection of expression involving header keywords that must match between an image and a master for a master to be useable for calibrating that image.

  description

    A description of the master file type.

  id

    A unique identifier for each row.

  maker_image_split_condition_id

    The collection of expression involving header keywords that must match between all images that are combined into a master in addition to the expressions specified by `condition_id`.

  maker_image_type_id

    The image type to which the maker step is applied when creating masters of this type.

  maker_step_id

    The step which produces this type of master frames.

  master_files
  match_expressions: Mapped[List[ConditionExpression]]
  name

    The name of the master file type.

  split_expressions: Mapped[List[ConditionExpression]]
  timestamp

    When record was last changed

class autowisp.database.data_model.ObservingSession(**kwargs)

  Bases: `DataModelBase`

  The table describing the observing session

  camera
  camera_id

    The id of the camera

  end_time_utc

    The end time of the observing session in UTC

  id

    A unique identifier for each row.

  images
  label

    Unique label assigned to the observing session

  mount
  mount_id

    The id of the mount

  notes

    The notes provided for the observing session

  observatory
  observatory_id

    The id of the observatory

  observer
  observer_id

    The id of the observer

  start_time_utc

    The start time of the observing session in UTC

  target
  target_id

    The id of the target

  telescope
  telescope_id

    The id of the telescope

  timestamp

    When record was last changed

class autowisp.database.data_model.Parameter(**kwargs)

  Bases: `DataModelBase`

  Table describing the configuration parameters needed by the pipeline.

  description

    Description of what the step does.

  id

    A unique identifier for each row.

  name

    The name of the step within the pipeline.

  steps: Mapped[List[Step]]
  timestamp

    When record was last changed

class autowisp.database.data_model.ProcessedImages(**kwargs)

  Bases: `DataModelBase`

  The table describing the processed images/channels by each step.

  channel

    The channel of the image that was processed.

  final

    Is this the final processing status? The only case where `status=1` is not final is for magnitude fitting, where there may be additional iterations needed.

  id

    A unique identifier for each row.

  image
  image_id

    The image that was processed.

  processing
  progress_id

    The id of the processing progress

  status

    The status of the processing (0 = started, >0 = successfully saved progress, negative values indicate various reasons for failure). The meaning of negative values is step dependent. For most steps 1 is the final status, but for magnitude fitting the value indicates the iteration.

  timestamp

    When record was last changed

class autowisp.database.data_model.ProcessingSequence(**kwargs)

  Bases: `DataModelBase`

  The sequence of steps/image type to be processed by the pipeline.

  id

    A unique identifier for each row.

  image_type
  image_type_id

    The image type to be processed by the step.

  step
  step_id

    The step to be executed.

  timestamp

    When record was last changed

class autowisp.database.data_model.Step(**kwargs)

  Bases: `DataModelBase`

  The table describing the processing steps constituting the pipeline

  description

    Description of what the step does.

  id

    A unique identifier for each row.

  name

    The name of the step within the pipeline.

  parameters: Mapped[List[Parameter]]
  prerequisites: Mapped[List[StepDependencies]]
  timestamp

    When record was last changed

class autowisp.database.data_model.StepDependencies(**kwargs)

  Bases: `DataModelBase`

  The table describing the prerequisites for a step to run

  __str__()

    Describe the dependency.

  blocked_image_type_id

    The image type for which this prerequisite applies.

  blocked_imtype
  blocked_step
  blocked_step_id

    The step for which this prerequisite applies.

  blocking_image_type_id

    The image type for which the prerequisite step must be completed.

  blocking_imtype
  blocking_step
  blocking_step_id

    The step which must be completed before the blocked step can begin.

  id

    A unique identifier for each row.

  timestamp

    When record was last changed

class autowisp.database.data_model.Target(**kwargs)

  Bases: `DataModelBase`

  The table dsecribing the target.

  dec

    The dec of the target

  id

    A unique identifier for each row.

  name

    The name of the target

  notes

    The notes about the target

  observing_sessions
  ra

    The ra of the target

  timestamp

    When record was last changed

## Subpackages

- autowisp.database.data_model.provenance package
  - Class Inheritance Diagram
  - `Camera`
    - `Camera.__str__()`
    - `Camera.camera_type`
    - `Camera.camera_type_id`
    - `Camera.channels`
    - `Camera.id`
    - `Camera.notes`
    - `Camera.observers`
    - `Camera.observing_sessions`
    - `Camera.serial_number`
    - `Camera.timestamp`
  - `CameraAccess`
    - `CameraAccess.camera_id`
    - `CameraAccess.id`
    - `CameraAccess.observer_id`
    - `CameraAccess.timestamp`
  - `CameraChannel`
    - `CameraChannel.camera_type_id`
    - `CameraChannel.id`
    - `CameraChannel.name`
    - `CameraChannel.timestamp`
    - `CameraChannel.x_offset`
    - `CameraChannel.x_step`
    - `CameraChannel.y_offset`
    - `CameraChannel.y_step`
  - `CameraType`
    - `CameraType.cameras`
    - `CameraType.channels`
    - `CameraType.id`
    - `CameraType.make`
    - `CameraType.model`
    - `CameraType.notes`
    - `CameraType.pixel_size`
    - `CameraType.sensor_type`
    - `CameraType.timestamp`
    - `CameraType.version`
    - `CameraType.x_resolution`
    - `CameraType.y_resolution`
  - `Mount`
    - `Mount.__str__()`
    - `Mount.id`
    - `Mount.mount_type`
    - `Mount.mount_type_id`
    - `Mount.notes`
    - `Mount.observers`
    - `Mount.observing_sessions`
    - `Mount.serial_number`
    - `Mount.timestamp`
  - `MountAccess`
    - `MountAccess.id`
    - `MountAccess.mount_id`
    - `MountAccess.observer_id`
    - `MountAccess.timestamp`
  - `MountType`
    - `MountType.id`
    - `MountType.make`
    - `MountType.model`
    - `MountType.mounts`
    - `MountType.notes`
    - `MountType.timestamp`
    - `MountType.version`
  - `Observatory`
    - `Observatory.__str__()`
    - `Observatory.altitude`
    - `Observatory.id`
    - `Observatory.latitude`
    - `Observatory.longitude`
    - `Observatory.name`
    - `Observatory.observing_sessions`
    - `Observatory.timestamp`
  - `Observer`
    - `Observer.__str__()`
    - `Observer.cameras`
    - `Observer.email`
    - `Observer.id`
    - `Observer.mounts`
    - `Observer.name`
    - `Observer.notes`
    - `Observer.observing_sessions`
    - `Observer.phone`
    - `Observer.telescopes`
    - `Observer.timestamp`
  - `Telescope`
    - `Telescope.__str__()`
    - `Telescope.id`
    - `Telescope.notes`
    - `Telescope.observers`
    - `Telescope.observing_sessions`
    - `Telescope.serial_number`
    - `Telescope.telescope_type`
    - `Telescope.telescope_type_id`
    - `Telescope.timestamp`
  - `TelescopeAccess`
    - `TelescopeAccess.id`
    - `TelescopeAccess.observer_id`
    - `TelescopeAccess.telescope_id`
    - `TelescopeAccess.timestamp`
  - `TelescopeType`
    - `TelescopeType.f_ratio`
    - `TelescopeType.focal_length`
    - `TelescopeType.id`
    - `TelescopeType.make`
    - `TelescopeType.model`
    - `TelescopeType.notes`
    - `TelescopeType.telescopes`
    - `TelescopeType.timestamp`
    - `TelescopeType.version`
  - Submodules
    - autowisp.database.data_model.provenance.camera module
      - Class Inheritance Diagram
      - `Camera`
    - autowisp.database.data_model.provenance.camera_access module
      - Class Inheritance Diagram
      - `CameraAccess`
    - autowisp.database.data_model.provenance.camera_channel module
      - Class Inheritance Diagram
      - `CameraChannel`
    - autowisp.database.data_model.provenance.camera_type module
      - Class Inheritance Diagram
      - `CameraType`
    - autowisp.database.data_model.provenance.mount module
      - Class Inheritance Diagram
      - `Mount`
    - autowisp.database.data_model.provenance.mount_access module
      - Class Inheritance Diagram
      - `MountAccess`
    - autowisp.database.data_model.provenance.mount_type module
      - Class Inheritance Diagram
      - `MountType`
    - autowisp.database.data_model.provenance.observatory module
      - Class Inheritance Diagram
      - `Observatory`
    - autowisp.database.data_model.provenance.observer module
      - Class Inheritance Diagram
      - `Observer`
    - autowisp.database.data_model.provenance.telescope module
      - Class Inheritance Diagram
      - `Telescope`
    - autowisp.database.data_model.provenance.telescope_access module
      - Class Inheritance Diagram
      - `TelescopeAccess`
    - autowisp.database.data_model.provenance.telescope_type module
      - Class Inheritance Diagram
      - `TelescopeType`

## Submodules

- autowisp.database.data_model.base module
  - Class Inheritance Diagram
  - `DataModelBase`
    - `DataModelBase.describe_table()`
    - `DataModelBase.id`
    - `DataModelBase.metadata`
    - `DataModelBase.registry`
    - `DataModelBase.timestamp`
- autowisp.database.data_model.condition module
  - Class Inheritance Diagram
  - `Condition`
    - `Condition.expression`
    - `Condition.expression_id`
    - `Condition.id`
    - `Condition.notes`
    - `Condition.timestamp`
- autowisp.database.data_model.condition_expression module
  - Class Inheritance Diagram
  - `ConditionExpression`
    - `ConditionExpression.expression`
    - `ConditionExpression.id`
    - `ConditionExpression.notes`
    - `ConditionExpression.timestamp`
- autowisp.database.data_model.configuration module
  - Class Inheritance Diagram
  - `Configuration`
    - `Configuration.condition_expressions`
    - `Configuration.condition_id`
    - `Configuration.conditions`
    - `Configuration.id`
    - `Configuration.notes`
    - `Configuration.parameter`
    - `Configuration.parameter_id`
    - `Configuration.timestamp`
    - `Configuration.value`
    - `Configuration.version`
- autowisp.database.data_model.hdf5_attributes module
  - Class Inheritance Diagram
  - `HDF5Attribute`
    - `HDF5Attribute.__str__()`
    - `HDF5Attribute.description`
    - `HDF5Attribute.dtype`
    - `HDF5Attribute.hdf5_structure_version_id`
    - `HDF5Attribute.id`
    - `HDF5Attribute.name`
    - `HDF5Attribute.parent`
    - `HDF5Attribute.pipeline_key`
    - `HDF5Attribute.structure_version`
    - `HDF5Attribute.timestamp`
- autowisp.database.data_model.hdf5_datasets module
  - Class Inheritance Diagram
  - `HDF5DataSet`
    - `HDF5DataSet.__str__()`
    - `HDF5DataSet.abspath`
    - `HDF5DataSet.compression`
    - `HDF5DataSet.compression_options`
    - `HDF5DataSet.description`
    - `HDF5DataSet.dtype`
    - `HDF5DataSet.hdf5_structure_version_id`
    - `HDF5DataSet.id`
    - `HDF5DataSet.pipeline_key`
    - `HDF5DataSet.replace_nonfinite`
    - `HDF5DataSet.scaleoffset`
    - `HDF5DataSet.shuffle`
    - `HDF5DataSet.structure_version`
    - `HDF5DataSet.timestamp`
- autowisp.database.data_model.hdf5_links module
  - Class Inheritance Diagram
  - `HDF5Link`
    - `HDF5Link.abspath`
    - `HDF5Link.description`
    - `HDF5Link.hdf5_structure_version_id`
    - `HDF5Link.id`
    - `HDF5Link.pipeline_key`
    - `HDF5Link.structure_version`
    - `HDF5Link.target`
    - `HDF5Link.timestamp`
- autowisp.database.data_model.hdf5_products module
  - Class Inheritance Diagram
  - `HDF5Product`
    - `HDF5Product.description`
    - `HDF5Product.id`
    - `HDF5Product.pipeline_key`
    - `HDF5Product.structure_versions`
    - `HDF5Product.timestamp`
- autowisp.database.data_model.hdf5_structure_versions module
  - Class Inheritance Diagram
  - `HDF5StructureVersion`
    - `HDF5StructureVersion.attributes`
    - `HDF5StructureVersion.datasets`
    - `HDF5StructureVersion.hdf5_product_id`
    - `HDF5StructureVersion.id`
    - `HDF5StructureVersion.links`
    - `HDF5StructureVersion.product`
    - `HDF5StructureVersion.timestamp`
    - `HDF5StructureVersion.version`
- autowisp.database.data_model.image module
  - Class Inheritance Diagram
  - `Image`
    - `Image.id`
    - `Image.image_type`
    - `Image.image_type_id`
    - `Image.notes`
    - `Image.observing_session`
    - `Image.observing_session_id`
    - `Image.processing`
    - `Image.raw_fname`
    - `Image.timestamp`
  - `ImageProcessingProgress`
    - `ImageProcessingProgress.applied_to`
    - `ImageProcessingProgress.configuration_version`
    - `ImageProcessingProgress.finished`
    - `ImageProcessingProgress.host`
    - `ImageProcessingProgress.id`
    - `ImageProcessingProgress.image_type`
    - `ImageProcessingProgress.image_type_id`
    - `ImageProcessingProgress.notes`
    - `ImageProcessingProgress.process_id`
    - `ImageProcessingProgress.started`
    - `ImageProcessingProgress.step`
    - `ImageProcessingProgress.step_id`
    - `ImageProcessingProgress.timestamp`
  - `ProcessedImages`
    - `ProcessedImages.channel`
    - `ProcessedImages.final`
    - `ProcessedImages.id`
    - `ProcessedImages.image`
    - `ProcessedImages.image_id`
    - `ProcessedImages.processing`
    - `ProcessedImages.progress_id`
    - `ProcessedImages.status`
    - `ProcessedImages.timestamp`
- autowisp.database.data_model.image_type module
  - Class Inheritance Diagram
  - `ImageType`
    - `ImageType.description`
    - `ImageType.id`
    - `ImageType.image`
    - `ImageType.name`
    - `ImageType.timestamp`
- autowisp.database.data_model.input_master_types module
  - Class Inheritance Diagram
  - `InputMasterTypes`
    - `InputMasterTypes.config_name`
    - `InputMasterTypes.id`
    - `InputMasterTypes.image_type`
    - `InputMasterTypes.image_type_id`
    - `InputMasterTypes.master_type`
    - `InputMasterTypes.master_type_id`
    - `InputMasterTypes.optional`
    - `InputMasterTypes.step`
    - `InputMasterTypes.step_id`
    - `InputMasterTypes.timestamp`
- autowisp.database.data_model.light_curve_processing_progress module
  - Class Inheritance Diagram
  - `LightCurveProcessingProgress`
    - `LightCurveProcessingProgress.configuration_version`
    - `LightCurveProcessingProgress.final`
    - `LightCurveProcessingProgress.finished`
    - `LightCurveProcessingProgress.host`
    - `LightCurveProcessingProgress.id`
    - `LightCurveProcessingProgress.notes`
    - `LightCurveProcessingProgress.process_id`
    - `LightCurveProcessingProgress.single_photref_id`
    - `LightCurveProcessingProgress.sphotref`
    - `LightCurveProcessingProgress.started`
    - `LightCurveProcessingProgress.step`
    - `LightCurveProcessingProgress.step_id`
    - `LightCurveProcessingProgress.timestamp`
- autowisp.database.data_model.light_curve_status module
  - Class Inheritance Diagram
  - `LightCurveStatus`
    - `LightCurveStatus.id`
    - `LightCurveStatus.processing`
    - `LightCurveStatus.progress_id`
    - `LightCurveStatus.status`
    - `LightCurveStatus.timestamp`
- autowisp.database.data_model.master_files module
  - Class Inheritance Diagram
  - `MasterFile`
    - `MasterFile.enabled`
    - `MasterFile.filename`
    - `MasterFile.id`
    - `MasterFile.master_type`
    - `MasterFile.progress_id`
    - `MasterFile.timestamp`
    - `MasterFile.type_id`
    - `MasterFile.use_smallest`
  - `MasterType`
    - `MasterType.condition_id`
    - `MasterType.description`
    - `MasterType.id`
    - `MasterType.maker_image_split_condition_id`
    - `MasterType.maker_image_type_id`
    - `MasterType.maker_step_id`
    - `MasterType.master_files`
    - `MasterType.match_expressions`
    - `MasterType.name`
    - `MasterType.split_expressions`
    - `MasterType.timestamp`
- autowisp.database.data_model.observing_session module
  - Class Inheritance Diagram
  - `ObservingSession`
    - `ObservingSession.camera`
    - `ObservingSession.camera_id`
    - `ObservingSession.end_time_utc`
    - `ObservingSession.id`
    - `ObservingSession.images`
    - `ObservingSession.label`
    - `ObservingSession.mount`
    - `ObservingSession.mount_id`
    - `ObservingSession.notes`
    - `ObservingSession.observatory`
    - `ObservingSession.observatory_id`
    - `ObservingSession.observer`
    - `ObservingSession.observer_id`
    - `ObservingSession.start_time_utc`
    - `ObservingSession.target`
    - `ObservingSession.target_id`
    - `ObservingSession.telescope`
    - `ObservingSession.telescope_id`
    - `ObservingSession.timestamp`
- autowisp.database.data_model.processing_sequence module
  - Class Inheritance Diagram
  - `ProcessingSequence`
    - `ProcessingSequence.id`
    - `ProcessingSequence.image_type`
    - `ProcessingSequence.image_type_id`
    - `ProcessingSequence.step`
    - `ProcessingSequence.step_id`
    - `ProcessingSequence.timestamp`
- autowisp.database.data_model.step_dependencies module
  - Class Inheritance Diagram
  - `StepDependencies`
    - `StepDependencies.__str__()`
    - `StepDependencies.blocked_image_type_id`
    - `StepDependencies.blocked_imtype`
    - `StepDependencies.blocked_step`
    - `StepDependencies.blocked_step_id`
    - `StepDependencies.blocking_image_type_id`
    - `StepDependencies.blocking_imtype`
    - `StepDependencies.blocking_step`
    - `StepDependencies.blocking_step_id`
    - `StepDependencies.id`
    - `StepDependencies.timestamp`
- autowisp.database.data_model.steps_and_parameters module
  - Class Inheritance Diagram
  - `Parameter`
    - `Parameter.description`
    - `Parameter.id`
    - `Parameter.name`
    - `Parameter.steps`
    - `Parameter.timestamp`
  - `Step`
    - `Step.description`
    - `Step.id`
    - `Step.name`
    - `Step.parameters`
    - `Step.prerequisites`
    - `Step.timestamp`
- autowisp.database.data_model.target module
  - Class Inheritance Diagram
  - `Target`
    - `Target.dec`
    - `Target.id`
    - `Target.name`
    - `Target.notes`
    - `Target.observing_sessions`
    - `Target.ra`
    - `Target.timestamp`